==> haskell-quickcheck-unicode-1.0.1.0-337.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-9k6S0FyLJqEH7AM684V2uz
key:                  quickcheck-unicode-1.0.1.0-9k6S0FyLJqEH7AM684V2uz
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  b65aed50724cd1fa9dae3068408872e7
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-unicode-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-9k6S0FyLJqEH7AM684V2uz
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-338-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-7XS6pkFGamCGsad4NnRLN
key:                  quickcheck-unicode-1.0.1.0-7XS6pkFGamCGsad4NnRLN
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  97dae2a1c134d736c0a70f5a7b05377f
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-unicode-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-7XS6pkFGamCGsad4NnRLN
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
